@@ -27,17 +27,24 @@ struct aes_regwrite {
 	unsigned char value;
 };
 
+struct aes_stripe {
+	int delta_x;
+	int delta_y;
+	unsigned char data[0];
+};
+
 typedef void (*aes_write_regv_cb)(struct fp_img_dev *dev, int result,
 	void *user_data);
 
 void aes_write_regv(struct fp_img_dev *dev, const struct aes_regwrite *regs,
 	unsigned int num_regs, aes_write_regv_cb callback, void *user_data);
 
-void aes_assemble_image(unsigned char *input, size_t width, size_t height,
-	unsigned char *output);
+unsigned int aes_calc_delta(GSList *stripes, size_t stripes_len,
+	unsigned int frame_width, unsigned int frame_height,
+	gboolean reverse);
 
 struct fp_img *aes_assemble(GSList *stripes, size_t stripes_len,
-	unsigned int frame_width, unsigned int frame_height);
+	unsigned int frame_width, unsigned int frame_height, unsigned int img_width);
 
 #endif
 
